#!/usr/bin/env python3


# Shuttle Information's
__version__ = "0.3.0"
__license__ = "AGPL-3.0"
__author__ = "Meheret Tesfaye"
__email__ = "meherett@zoho.com"


__all__ = [
    "__version__",
    "__license__",
    "__author__",
    "__email__"
]
